<?php

// Admin action hooks
add_action( 'admin_init' , 'wpsub_admin_init' );
add_action( 'admin_menu' , 'wpsub_menu' );
add_action( 'admin_enqueue_scripts', 'wpsub_admin_scripts' );




// Adding admin style
function wpsub_admin_init() {
	wp_register_style( 'slideupbox_style', plugins_url('css/slideupbox-admin.css', __FILE__) );
}




// Admin page
function wpsub_menu() {
	$page = add_submenu_page( 'themes.php',
		'WP Slide-up box',
		'WP Slide-up box',
		'manage_options',
		'wp-slideup-box',
		'wpsub_options' );

	add_action( 'admin_print_styles-' . $page, 'wpsub_admin_styles' );
}




// JS functions for admin panel
function wpsub_admin_scripts () {
	wp_enqueue_script(
		'wpsub-admin-scripts',
		plugins_url('', __FILE__) . '/js/wpsub_admin.js',
		array('jquery')
	);
}





// Load admin page style
function wpsub_admin_styles() {
	wp_enqueue_style( 'slideupbox_style' );
}





// This function handles the admin page of the plugin
function wpsub_options() {

	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
	}

	$pdata = get_plugin_data( dirname( __FILE__ ) . '/slideupbox.php' );

	echo '
	<div class="wrap">
		<h2>WP Slide-up box</h2>

		<div id="wpsub-addnewe">
		<h2>Shortcode Generator</h2>
		<form name="wpsub_addnew" method="post" action="' . $_SERVER["REQUEST_URI"] . '"><table class="wpsub_formtable">
			<tr>
				<td>Image ID or URL*:</td><td><input type="text" name="wpsub_imgid" id="wpsub_imgid" /></td>
			</tr>
			<tr>
				<td>Mode:</td><td>
					<select name="wpsub_mode" id="wpsub_mode">
						<option value="bottom-up-full">bottom-up-full</option>
						<option value="bottom-up-part">bottom-up-part</option>
						<option value="left-right">left-right</option>
						<option value="left-right-uncover">left-right-uncover</option>
						<option value="right-left">right-left</option>
						<option value="right-left-uncover">right-left-uncover</option>
						<option value="fade-in">fade-in</option>
						<option value="fade-out">fade-out</option>
						<option value="top-down-full">top-down-full</option>
						<option value="top-down-part">top-down-part</option>
					</select>
				</td>
			</tr>
			<tr>
				<td>Title text:</td><td><input type="text" name="wpsub_title" id="wpsub_title" /></td>
			</tr>
			<tr>
				<td>Description:</td><td><input type="text" name="wpsub_desc" id="wpsub_desc" /></td>
			</tr>
			<tr>
				<td>Target URL:</td><td><input type="text" name="wpsub_target" id="wpsub_target" /></td>
			</tr>
			<tr>
				<td>Extra class:</td><td><input type="text" name="wpsub_class" id="wpsub_class" /></td>
			</tr>
			<tr>
				<td>Image alt text:</td><td><input type="text" name="wpsub_alt" id="wpsub_alt" /></td>
			</tr>
			<tr id="wpsub-size-row">
				<td>Size:</td><td>
					<select name="wpsub_size" id="wpsub_size">';

		foreach ( get_intermediate_image_sizes() as $size ) {
			echo '<option value="' . $size . '">' . $size . '</option>';
		}

		echo '			</select>
				</td>
			</tr>
			<tr>
				<td></td><td><input id="wpsub-generate" type="submit" value="Generate shortcode" /></td>
			</tr>
		</table>
		</form>
		<div id="shortcode-wrapper">
		</div>
		</div>

		<div id="wpsub-hints">
			<h2>Usage</h2>
			<ol>
				<li>Use the Shortcode generator form on this page</li>
				<li>Clicking on the Generate shortcode button will create the shortcode for you</li>
				<li>Copy the shortcode from here and paste it into the post or page you\'d like to use it in</li>
			</ol>
			<h3>A quick explanation about the different attributes:</h3>
			<ul>
				<li><strong>id:</strong> The attachment ID of the image. This is the only required field. <a href="https://a-idea.studio/blog/find-id-number-picture-wordpress/" target="_blank">Click here for a tutorial on how to find it.</a> Alternatively you can use the image URL here, too.</li>
				<li><strong>mode:</strong> The animation type for the box. To understand better how the different modes work, take a look at our <a href="https://a-idea.studio/wp-slide-up-box/modes-showcase/" target="_blank">Modes Showcase</a> page.</li>
				<li><strong>title:</strong> The text displayed on the top of the box.</li>
				<li><strong>desc:</strong> The longer text at the bottom part of the box. If you want to place a link in it use the next shorttag: {{link|http://www.example.com}}. (before the | goes the anchor text and after it the URL)</li>
				<li><strong>target:</strong> The URL the box should be linked to.</li>
				<li><strong>class:</strong> You can add extra classes to the box container with it.</li>
				<li><strong>alt:</strong> Alternative text for the background image. If not set, the title will be used.</li>
				<li><strong>size:</strong> Size of the image (defined with WordPress image sizes).</li>
			</ul>
			<p>For detiled tutorials and full documentation, <a href="https://a-idea.studio/wp-slide-up-box/" target="_blank">visit the plugin\'s official pages</a>.</p>
		</div>
	</div>';

}
