<?php
/*
Plugin Name: WP Slide-up box
Plugin URI: https://a-idea.studio/wp-slide-up-box/
Description: Add jQuery-driven fancy slideboxes to your WordPress pages and posts. With this plugin a layer will slide on an inserted picture on mouse hover.
Version: 0.4.1
Author: a-idea studio
Author URI: https://a-idea.studio/
*/


add_action( 'wp_enqueue_scripts' , 'wpsub_slideup_script' );
add_action( 'wp_enqueue_scripts', 'wpsub_add_my_stylesheet' );
add_shortcode( 'slideupbox', 'wpsub_shortcode' );

if ( is_admin() ) {
	require_once 'slideupbox-admin.php';
}



// Get a row from db table specified by id - DEPRECATED
function wpsub_get_row ( $id ) {

	global $wpdb;

	$table_name = $wpdb->prefix . "slideupbox";

	$supdb_row = $wpdb->get_row( "
		SELECT *
		FROM $table_name
		WHERE id=$id
		" , ARRAY_A );

	return $supdb_row;

}



// Shortcode handler function
function wpsub_shortcode ( $atts ) {

	extract( shortcode_atts( array(
		'id'		=> '',
		'mode'		=> 'bottom-up-full',
		'title'		=> '',
		'desc'		=> '',
		'target'	=> '',
		'class'		=> '',
		'alt'		=> '',
		'size'		=> 'full',
	), $atts ) );


	// Legacy support for the database, should be removed in a future version
	if ( $title == '' && $desc == '' ) {
		$row = wpsub_get_row ( $id, ARRAY_A );
	}


	// Check the height and width of the image
	if ( ctype_digit( $id ) ) {
		$imgsrc = wp_get_attachment_image_src( $id, $size );

		if ( $imgsrc !== false ) {
			$image_url = $imgsrc[0];
		}

	} else {
		$image_url = $id;
	}



	// Also some legacy code
	if ( isset( $row ) ) {
		if ( ( $title == '' ) && ( $row["stitle"] != '' ) ) {
			$title = $row["stitle"];
		}
		if ( ( $desc == '' ) && ( $row["sdesc"] != '' ) ) {
			$desc = $row["sdesc"];
		}
		if ( ( $target == '' ) && ( $row["target"] != '' ) ) {
			$target = $row["target"];
		}
	}

	// If no alt text was set, using the box title as the image alt text
	if ( $alt == '' ) {
		$alt = $title;
	}


	// Escape the description early
	if ( $desc != '' ) {
		$desc = wp_kses( $desc, array(
			'br'	=> array(),
			'em'	=> array(),
			'strong'=> array(),
			'i'		=> array(),
			'b'		=> array(),
			'p'		=> array(),
			'span'	=> array(),
			'ul'	=> array(),
			'ol'	=> array(),
			'li'	=> array(),
		) );
	}


	// Print out the link in the description
	$notarget = false;

	while ( ( $link_pos = strpos( $desc, '{{' ) ) !== false ) {

		$tmp_desc = $desc;
		$end_pos = strpos( $tmp_desc, '}}' );
		$link = substr( $tmp_desc, $link_pos + 2, ( $end_pos - $link_pos - 2 ) );
		$sep_pos = strpos( $link, '|' );

		$desc = substr( $tmp_desc, 0, $link_pos ) . '<a href="' . esc_url( substr( $link, ( $sep_pos + 1 ) ) ) . '">' . substr( $link, 0, $sep_pos ) . '</a>' . substr( $tmp_desc, ($end_pos + 2) );

		// If the text has link dont show the target link
		$notarget = true;

	}



	// $rtext is the HTML content the shortcode will output
	if ( $class != '' ) {
		$class = ' ' . $class;
	}

	$rtext = '<div id="slideup_' . esc_attr( $id ) . '" class="wpsub-boxgrid' . esc_attr( $class ) . '">';

	if ( $target != '' && !$notarget ) {
		$rtext .= '<a class="wpsub-target" href="' . esc_url( $target ) . '"><div>';
	}

	if ( $id != '' ) {
		$rtext .= '<img class="wpsub-background" src="' . esc_url( $image_url ) . '" alt="' . $alt . '" />';
	}

	$rtext .= '<div class="cover ' . $mode . '">';

	$rtext .= '<h3 class="slideup_title">' . esc_html( $title ) . '</h3>';
	$rtext .= '<p class="slideup_desc">' . $desc . '</p>';
	$rtext .= '</div>';

	if ( $target != '' && !$notarget ) {
		$rtext .= '<a class="wpsub-target-mobile" href="' . esc_url( $target ) . '"></a>';
	}

	if ( $target != '' && !$notarget ) {
		$rtext .= '</div></a>';
	}

	$rtext .= '</div>
	';

	return $rtext;

}



// Use this function if you'd like to insert Slide-up box into your templates, loops, etc.
function wpsub_slideupbox ( $arr ) {

	if ( !isset( $arr['mode'] ) ) {
		$arr['mode'] = 'bottom-up-full';
	}

	$shortcode = '[slideupbox';

	foreach ( $arr as $key => $value ) {
		$shortcode .= ' ' . $key . '="' . $value . '"';
	}

	$shortcode .= ']';

	echo do_shortcode( $shortcode );

}



// Load the frontend JS
function wpsub_slideup_script () {

	wp_enqueue_script(
		'slideup-script',
		plugins_url( '', __FILE__ ) . '/js/slideup.js',
		array( 'jquery' )
	);

}


// Load the fronend CSS
function wpsub_add_my_stylesheet () {
    wp_register_style( 'wpsub-style', plugins_url( 'css/slideupbox.css' , __FILE__ ) );
    wp_enqueue_style( 'wpsub-style' );
}
